@@ -2,17 +2,19 @@
 #######################################################################
 """Next-Previous view adapter class
 
-$Id: nextprev.py 51213 2008-06-30 12:42:36Z cray $
+$Id: nextprev.py 51888 2008-10-21 07:10:48Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51213 $"
+__version__ = "$Revision: 51888 $"
 
 from zope.publisher.browser import BrowserView    
-from zope.interface import implements
+from zope.interface import implements,Interface
 from interfaces import INextPrev
 from ng.adapter.pager.interfaces import  IPagerSource
 from ng.content.article.maincontainer.interfaces import IMainPage
+from ng.content.article.interfaces import IContentContainer
+from zope.app.zapi import absoluteURL,getMultiAdapter
 
 class NextPrev(BrowserView) :
     __doc__ = __doc__
@@ -22,12 +24,14 @@ class NextPrev(BrowserView) :
     
     def __init__(self,*kv,**kw) :
         super(NextPrev,self).__init__(*kv,**kw)
-        up = IPagerSource(self.up)
+        up = IPagerSource(IContentContainer(self.up))
 
         keys = up.keys()
         index = keys.index(self.context.__name__)
+
         if index :
             self.prev = self.up[keys[index-1]]
+
         if index < len(keys)-1 :
             self.next = self.up[keys[index+1]]
 
