@@ -2,11 +2,11 @@
 #######################################################################
 """MixIn class for backreference viewlet.
 
-$Id: viewletbackref.py 51213 2008-06-30 12:42:36Z cray $
+$Id: viewletbackref.py 51888 2008-10-21 07:10:48Z cray $
 """
 __author__  = "Andrey Orlov,2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51213 $"
+__version__ = "$Revision: 51888 $"
 
 from ng.site.content.search.interfaces import ISearch, ISearchName
 from zope.app import zapi 
@@ -25,13 +25,13 @@ class ViewletBackRef(ViewletBase) :
         else :  
             for item in zapi.getUtility(
                     zope.app.catalog.interfaces.ICatalog,
-                    name="catalog",context=self.context). \
+                    context=self.context). \
                     searchResults(backkeyword={'any_of':keyword}) :
                 yield item                    
                     
         for item in zapi.getUtility(
                     zope.app.catalog.interfaces.ICatalog,
-                    name="catalog",context=self.context). \
+                    context=self.context). \
                     searchResults(backname={'any_of':ISearchName(self.context).name}) :
             yield item
                                 
\ No newline at end of file
