@@ -2,11 +2,11 @@
 #######################################################################
 """MixIn class for searchpage.
 
-$Id: searchpage.py 51213 2008-06-30 12:42:36Z cray $
+$Id: searchpage.py 51888 2008-10-21 07:10:48Z cray $
 """
 __author__  = "Andrey Orlov 2006 12 05"
 __license__ = "GPL"
-__version__ = "$Revision: 51213 $"
+__version__ = "$Revision: 51888 $"
 
 import zope.component
 from zope.app import zapi
@@ -70,9 +70,16 @@ class Search(object) :
         elif 'urlpath' in d :            
             path=IPath(self.context).path
             d['urlpath'] = (path,path+u'\xff')
-            
         
-        res = zapi.getUtility(ICatalog,name="catalog",context=self.context).searchResults(**d)        
+        if 'nickname' in d and not d['nickname'] :
+            del d['nickname']
+
+        if 'email' in d and not d['email'] :
+            del d['email']
+        
+        print d
+        res = zapi.getUtility(ICatalog,context=self.context).searchResults(**d)        
+        print res
         pagersource = ResultSet2PagerSourceAdapter(res)
 
         if len(res) == 0 :
