@@ -3,11 +3,11 @@
 """MixIn class for undefined page provide list all references on unknown
 documents
 
-$Id: undefined.py 51213 2008-06-30 12:42:36Z cray $
+$Id: undefined.py 51888 2008-10-21 07:10:48Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51213 $"
+__version__ = "$Revision: 51888 $"
  
 from zope.interface import implements
 from zc.catalog.interfaces import IIndexValues
@@ -17,7 +17,7 @@ from zope.app.zapi import getUtility
 class UnDefined(object) :
     def undefined(self,backindexname,indexname) :
         index = getUtility(IIndexValues, context=self.context, name=backindexname)
-        catalog = getUtility(ICatalog,context=self.context, name='catalog')
+        catalog = getUtility(ICatalog,context=self.context)
         for keyword in index.values() :
             if len(catalog.searchResults(**{indexname:{'any_of':(keyword,keyword)}})) == 0 :
                 yield {
