@@ -3,18 +3,20 @@
 """Base class for a few viewlet display different folderish content
 as menu.
 
-$Id: mainbox.py 51213 2008-06-30 12:42:36Z cray $
+$Id: mainbox.py 51888 2008-10-21 07:10:48Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51213 $"
+__version__ = "$Revision: 51888 $"
 
 from zope.app.container.interfaces import IContainer
 from zope.app.zapi import getSiteManager
-
+from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
+        
 class MainBox(object) :
     """ Folder List """
 
+    template = ViewPageTemplateFile("mainbox.pt")
     foldername = "Main"
     folderinterface = IContainer
     order = 0
