@@ -2,11 +2,11 @@
 #######################################################################
 """Mix-in class for viewlet with last rss news
 
-$Id: newslistbox.py 51213 2008-06-30 12:42:36Z cray $
+$Id: newslistbox.py 51888 2008-10-21 07:10:48Z cray $
 """
 __author__  = "Andrey Orlov,2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51213 $"
+__version__ = "$Revision: 51888 $"
 
 
 from mainbox import MainBox
@@ -20,3 +20,8 @@ class NewsListBox(MainBox) :
     def values(self) :
         return IObjectQueue(self.folder).values()        
 
+class CommonNewsListBox(NewsListBox) :
+    """ Folder List """
+
+    foldername = "Main"
+
